;;; Functions to simplify TEIlite development for BP

;; Author: Alexander Mikhailian <mikhailian@altern.org>
;; Keywords: count words region

(defun count-words-region (beginning end)
  "Print number of words in the region."
  (interactive "r")
  (message "Counting words in region ... ")
     
     ;;; 1. Set up appropriate conditions.
  (save-excursion
    (let ((count 0))
      (goto-char beginning)
     
     ;;; 2. Run the while loop.
      (while (and (< (point) end)
                  (re-search-forward "\\w+\\W*" end t))
        (setq count (1+ count)))
     
     ;;; 3. Send a message to the user.
      (cond ((zerop count)
             (message
              "The region does NOT have any words."))
            ((= 1 count)
             (message
              "The region has 1 word."))
            (t
             (message
              "The region has %d words." count))))))


(defun tag-razdiel (beginning end)
  "Tags all razdiels"
  (interactive "r")     
  (save-excursion
    (let ((counter 0))
      (goto-char beginning)
      (while (< (point) end)
        (re-search-forward "^\\(,L@PWTWU[(B .+\\)$" end)
        (replace-match "<head>\\1</head>" t nil)
        (setq counter (1+ counter)))
      (message
       "Replaced words: %d" counter))))


(defun tag-title (beginning end)
  "Tags all titles"
  (interactive "r")     
  (save-excursion
    (let ((counter 0))
      (goto-char beginning)
      (while (< (point) end)
        (re-search-forward "\\(^[,L012345!67&9:;<=>?@ABCDEFGHLKMNO(B]+ [,L012345!67&9:;<=>?@ABCDEFGHLKMNO(B ]+$\\)" end)
        (replace-match "<head>\\1</head>" t nil)
        (setq counter (1+ counter)))
      (message
       "Replaced words: %d" counter))))


(defun tag-with-head (beginning end)
  "Tags with <head/>"
  (interactive "r")     
  (save-excursion
    (let ((counter 0))
      (goto-char beginning)
      (while (< (point) end)
        (re-search-forward "\\(.+\\)$" end)
        (replace-match "<head>\\1</head>" t nil)
        (setq counter (1+ counter)))
      (message
       "Replaced words: %d" counter))))


(defun tag-with-epigraph (beginning end)
  "Tags with <epigraph/>"
  (interactive "r")     
  (save-excursion
    (let ((counter 0))
      (goto-char beginning)
      (while (< (point) end)
        (re-search-forward "\\(.+\\)\n\\(.+$\\)" end)
        (replace-match "<epigraph><q who=\"\\2\">\n\\1\n</q></epigraph>" t nil)
        (setq counter (1+ counter)))
      (message
       "Replaced words: %d" counter))))


(defun tag-with-l (beginning end)
  "Tags all lines in the region"
  (interactive "r")     
  (save-excursion
    (let ((counter 0))
      (goto-char beginning)
      (while (< (point) end)
        (re-search-forward "^\\(.+\\)$" end)
        (replace-match "<l>\\1</l>" t nil)
        (setq counter (1+ counter)))
      (message
       "Replaced words: %d" counter))))


(defun tag-with-lg (beginning end)
  "Tags the region with <lg/>"
  (interactive "r")     
  (save-excursion
    (let ((counter 0))
      (goto-char beginning)
      (while (< (point) end)
        (re-search-forward "\\(.+\\)" end)
        (replace-match "<lg>\\1</lg>" t nil)
        (setq counter (1+ counter)))
      (message
       "Replaced words: %d" counter))))


(defun tag-paragraph (beginning end)
  "Tags all paragraphs in the region"
  (interactive "r")     
  (save-excursion
    (let ((counter 0))
      (goto-char beginning)
      (while (< (point) end)
        (re-search-forward "^\\(.*\\)$" end)
        (replace-match "<p>\\1</p>" t nil)
        (setq end (+ end 7))
        (setq counter (1+ counter)))
      (message
       "Replaced words: %d" counter))))


(defun retag-with-epigraph (beginning end)
  "Retags with <epigraph/>"
  (interactive "r")     
  (save-excursion
    (let ((counter 0))
      (goto-char beginning)
      (while (< (point) end)
        (re-search-forward "<q who=\"\\(.+?\\)\">\\([^,Lj(B]+?\\)</q>" end)
        (replace-match "<cit><quote>\\2</quote>\n<bibl>\\1</bibl></cit>" t nil)
        (setq counter (1+ counter)))
      (message
       "Replaced words: %d" counter))))

      <div1>
        <head>,L@PWTWU[(B ,L&&&(B</head>
        <head>,LAC4(B</head>
        <epigraph>
          <q who=",L:v_[v]S(B">
          <lg>
<l>,L&(B ,LacT(B ,LQk~(B ,LRU`]k(B,,LoZ(B ,L_ob[o(B,</l>
<l>,L&(B ,LecbZv(B, ,LQk(B ,LW(B ,LfU\`k(B ,L]PVk(B,</l>
<l>,L&(B ,Lgk\(B ,LTP~VmYhk(B ,LbR^Y(B ,LZPhm[l(B &mdash; </l>
<l>,LBk\(B ,LT^[UY(B ,LbPQU(B ,L_`PVkfl(B.</l>
            </lg>            
          </q>         
        </epigraph>


        <epigraph>          
          <q who=",L@PQ[U(B">
<p>,L;nTWv(B ,LbPZ(B ,LTP(B ,Lve(B ,L_`kRkZ[v(B, ,Lhb^(B ,L_U`PabP[v(B ,LWP~RPVPfl(B ,Lve]vo(B ,LW[Pgk]abRk(B...</p>
<p>...,LBP\c(B ,L\k(B ,L]U(B ,L_P[nU\(B ,LWP(B ,LQcY]k\v(B ,L`PWQ^Y]vZP\v(B, ,LP[U(B ,LWPb^U(B ,LRPhP\c(B ,LQ`Pbc(B ,La_caZc(B ,L]U(B ,LTPq\(B.</p>
          </q>
        </epigraph>
